@@ -42,6 +42,7 @@ extern "C" {
 typedef struct {
 	GtkObject base;
 	int model_col;
+	int compare_col;
 	char *title;
 	char *pixbuf;
 
@@ -52,6 +53,7 @@ typedef struct {
 
 	char *cell;
 	char *compare;
+	char *search;
 	int priority;
 } ETableColumnSpecification;
 
